@@ -21,7 +21,7 @@ __docformat__ = 'reStructuredText'
 from inspect import getmembers
 
 from .advisor import advisor
-from .functions import _wrapped_call
+from .functions import _wrapped_callable
 
 class _AOPDescriptor(object):
 
@@ -72,11 +72,8 @@ class _AOPDescriptor(object):
             'get', (obj,), {})
 
         # must wrap callables, to advice the call
-        if hasattr(retval, '__call__'): 
-            def g(*args, **kwargs):
-                return _wrapped_call(obj, self.__get_name(obj), retval, args, kwargs)
-
-            return g
+        if callable(retval): 
+            return _wrapped_callable(obj, self.__get_name(obj), retval)
         else:
             return retval
 
