@@ -18,7 +18,6 @@
 
 __docformat__ = 'reStructuredText'
 
-import logging
 from inspect import isclass
 
 from pytilities.tests import is_public, is_special
@@ -27,6 +26,7 @@ from . import AOPException
 from ._suppressor import _Suppressor
 from ._aspectassociations import _AspectAssociations
 
+import logging
 _logger = logging.getLogger('pytilities.aop.advisor')
 
 class Advisor(object):
@@ -75,10 +75,12 @@ class Advisor(object):
         See if an attribute with name `name` is advisable.
 
         Advisable members have a public or special name and aren't part of the
-        advisor.unadvisables collection
+        advisor.unadvisables collection.
         '''
-        return name not in self.unadvisables and (is_public(name) or
-                                                  is_special(name))
+        return (
+            name not in self.unadvisables and 
+            (is_public(name) or is_special(name))
+        )
 
     def get_applied_aspects(self, obj):
         '''
@@ -123,7 +125,7 @@ class Advisor(object):
         self._raise_if_cannot_apply(aspect, obj, members)
 
         if isclass(obj):
-            aspect.unapply(obj) #unapply instances
+            aspect.unapply(obj)
 
         if self._has_aopmeta_as_metaclass(obj):
              members = self._filter_attributes_supported_by_aopmeta(members)
