@@ -19,7 +19,7 @@
 __docformat__ = 'reStructuredText'
 
 from .advisor import advisor
-from .functions import _wrapped_call
+from .functions import _wrapped_callable
 
 def _make_attrs(base):
     # obj: either cls, or self, as in class (produced
@@ -34,11 +34,8 @@ def _make_attrs(base):
             'get', (obj,), {})
 
         # must wrap callables, to advice the call
-        if hasattr(retval, '__call__'): 
-            def g(*args, **kwargs):
-                return _wrapped_call(obj, name, retval, args, kwargs)
-
-            return g
+        if callable(retval): 
+            return _wrapped_callable(obj, name, retval)
         else:
             return retval
 
