@@ -18,12 +18,8 @@
 
 __docformat__ = 'reStructuredText'
 
-from collections import defaultdict
-from itertools import chain
-
 from .advisor import advisor
 from . import AOPException
-import pdb
 
 class Aspect(object):
 
@@ -37,23 +33,105 @@ class Aspect(object):
         self.__disabled_objects = set()
         '''set of objects for which this advice is disabled'''
 
-        self.__advice = defaultdict(dict)
+        self._advice_mappings = {}
         '''
-        All advice given by the aspect
-        {access : {member: advice}}
+        Mappings of (access, attribute_name) to advice to give or None, where
+        access is either 'get', 'set', 'delete' or 'call'.  Default value is 
+        {}.
+
+        Check `Advisor.is_advisable` for rules on valid `attribute_name`s
         '''
 
+        self._undefined_keys = False
+        '''
+        Boolean that indicates whether or not advice mappings has a sensible
+        result for keys(). Default is False.
+
+        Some mappings do not support keys because their set of keys is infinite
+        or hard to determine. (FunctionMap is an example of such Mappings)
+
+        If set to True, the aspect can only be applied to objects with AOPMeta 
+        as metaclass.
+        '''
+
+    def get_advice(self, attribute, access, obj):
+        '''
+        Get advice for `attribute` of `obj`.
+
+        Internal function
+
+        :param attribute: name of attribute to advise
+        :type attribute: str
+        :param access: the type of access being done
+        :type access: 'get', 'set', 'delete' or 'call'
+        :param obj: the object to advise
+        :type obj: class, instance
+        :return: advice func or None
+        '''
+        if not self.is_enabled(obj):
+            return None
+
+        try:
+            return self._advice_mappings[access, attribute]
+        except KeyError:
+            return None
+
+
+    ##################################################
+    # What advice should be given to which attributes
+    ##################################################
+
     @property
-    def __members(self):
+    def __advised_members(self):
         '''
         set of all advised members
         '''
-        return (self.__advice['get'].keys() 
-              | self.__advice['set'].keys()
-              | self.__advice['delete'].keys()
-              | self.__advice['call'].keys())
+        if self._undefined_keys:
+            return '*'
+        else:
+            return set((attr_name for (access, attr_name) in
+                        self._advice_mappings.keys()))
 
 
+    ####################################################
+    # To what objects is the aspect applied and enabled
+    ####################################################
+
+    def disable(self, obj):
+        '''
+        Disable advice for given object
+
+        Aspect must have been applied to object, before you can disable.
+
+        When this aspect is unapplied to the object, it is automatically
+        reenabled.
+
+        If `obj` was already disabled, do nothing.
+
+        :param obj: the object to advise
+        :type obj: class, instance
+        '''
+        if not self.is_applied(obj):
+            raise AOPException('Cannot disable aspect for an unapplied object')
+
+        self.__disabled_objects.add(obj)
+
+    def enable(self, obj):
+        '''
+        Enable advice for given object
+
+        Aspect must have been applied to object, before you can enable.
+
+        If `obj` was already enabled, do nothing.
+
+        :param obj: the object to advise
+        :type obj: class, instance
+        '''
+        if not self.is_applied(obj):
+            raise AOPException('Cannot enable aspect for an unapplied object')
+
+        self.__disabled_objects.discard(obj)
+
     def apply(self, obj):
         '''
         Apply the advice to the object
@@ -72,7 +150,7 @@ class Aspect(object):
         # Note on note: it's probably no issue that advice order is different
         # when given to all instances of a class, than to a single instance.
         # Given what you normally do with it, order doesn't really matter
-        advisor.apply(self, obj, self.__members)
+        advisor.apply(self, obj, self.__advised_members)
 
     def unapply(self, obj):
         '''
@@ -115,124 +193,3 @@ class Aspect(object):
         '''
         return self.is_applied(obj) and obj not in self.__disabled_objects
 
-    def get_advice(self, member, access, obj):
-        '''
-        Get advice for `member` of `obj`.
-
-        Internal function (its interface may change in the future).
-
-        :param member: member name of the object
-        :type member: str
-        :param access: the type of access being done
-        :type access: 'get', 'set', 'delete' or 'call'
-        :param obj: the object to advise
-        :type obj: class, instance
-        :return: advice func or None
-        '''
-        if not self.is_enabled(obj):
-            return None
-
-        advices = self.__advice[access]
-        if '*' in advices:
-            return advices['*']
-        elif member in advices:
-            return advices[member]
-        else: 
-            return None
-
-    def _advise(self, *members, get = None, set_ = None, delete = None, call = None):
-        '''
-        Associate advice to given members
-
-        You cannot advise the same member twice for the same type of access, 
-        this implies that you cannot give advise to the special '*' member 
-        and a regular member at the same for the same type of access.
-
-        A special member of '*' is allowed for advising classes with
-        metaclass=AOPMeta. This applies the advice to any member the applied
-        object may have. 
-
-        Check `Advisor.is_advisable` for further rules on what can be advised.
-
-        :param members: names of members to which to give advice
-        :type members: str, ...
-        :param get: around advice given to get calls
-        :type get: parameterless callable that returns a generator
-        :param set_: around advice given to set calls
-        :type set_: parameterless callable that returns a generator
-        :param delete: around advice given to del calls
-        :type delete: parameterless callable that returns a generator
-        :param call: around advice given to __call__ calls
-        :type call: parameterless callable that returns a generator
-        '''
-        self.__assert_no_conflicts(set(members), get, set_, delete, call)
-        for member in members:
-            if get:
-                self.__advice['get'][member] = get
-            if set_:
-                self.__advice['set'][member] = set_
-            if delete:
-                self.__advice['delete'][member] = delete
-            if call:
-                self.__advice['call'][member] = call
-
-    def __assert_no_conflicts(self, members, get, set_, delete, call):
-        '''
-        :param members: set of member names
-        '''
-        if get:
-            self.__assert_no_conflicting_members(members, self.__advice['get'])
-        if set_:
-            self.__assert_no_conflicting_members(members, self.__advice['set'])
-        if delete:
-            self.__assert_no_conflicting_members(members, self.__advice['delete'])
-        if call:
-            self.__assert_no_conflicting_members(members, self.__advice['call'])
-
-    def __assert_no_conflicting_members(self, new_members, current_members):
-        current_members = current_members.keys()
-        future_members = new_members | current_members
-        if '*' in future_members and len(future_members) > 1:
-            raise AOPException("Aspect can't advise '*' and other members " +
-                               "at the same time, for the same type of access")
-
-        common_members = new_members & current_members
-        if common_members:
-            raise AOPException('Tried to advise the same member twice, this ' +
-                               'is not supported by Aspect')
-
-    def disable(self, obj):
-        '''
-        Disable advice for given object
-
-        Aspect must have been applied to object, before you can disable.
-
-        When this aspect is unapplied to the object, it is automatically
-        reenabled.
-
-        If `obj` was already disabled, do nothing.
-
-        :param obj: the object to advise
-        :type obj: class, instance
-        '''
-        if not self.is_applied(obj):
-            raise AOPException('Cannot disable aspect for an unapplied object')
-
-        self.__disabled_objects.add(obj)
-
-    def enable(self, obj):
-        '''
-        Enable advice for given object
-
-        Aspect must have been applied to object, before you can enable.
-
-        If `obj` was already enabled, do nothing.
-
-        :param obj: the object to advise
-        :type obj: class, instance
-        '''
-        if not self.is_applied(obj):
-            raise AOPException('Cannot enable aspect for an unapplied object')
-
-        self.__disabled_objects.discard(obj)
-
