@@ -22,6 +22,7 @@ from pytilities.descriptors import AttributeDescriptor
 from pytilities.delegation import DelegationAspect
 from pytilities.aop import AOPMeta, Aspect
 from pytilities import aop
+from pytilities.dictionary import FunctionMap
 
 def create_view(aspect):
 
@@ -67,8 +68,15 @@ def create_view(aspect):
 class _ViewAspect(Aspect):
     def __init__(self):
         Aspect.__init__(self)
-        self._advise('*', get=self._advice, set_=self._advice,
-                    delete=self._advice, call=self._advice)
+        self._advice_mappings = FunctionMap(self._mapper)
+        self._undefined_keys = True
+
+    def _mapper(self, key):
+        access, attribute_name = key
+        if access == 'call':
+            return None
+        else:
+            return self._advice
 
     def _advice(self):
         with (yield aop.suppress_aspect):
@@ -76,9 +84,17 @@ class _ViewAspect(Aspect):
             aspect = view.__class__._aspect
             wrapped_object = view._View__wrapped_object
             aspect.enable(wrapped_object)
-            yield aop.proceed
+            return_value = yield aop.proceed
             aspect.disable(wrapped_object)
 
+            if callable(return_value):
+                def g(*args, **kwargs):
+                    aspect.enable(wrapped_object)
+                    return return_value(*args, **kwargs)
+                    aspect.disable(wrapped_object)
+
+                yield aop.return_(g)
+
 _view_aspect = _ViewAspect()
 
 _delegation_aspect = DelegationAspect(
