@@ -20,6 +20,21 @@ __docformat__ = 'reStructuredText'
 
 from .advisor import advisor
 
+class _CallableWrapper(object):
+    def __init__(self, obj, name, f):
+        self.obj = obj
+        self.name = name
+        self.f = f
+
+    def __call__(self, *args, **kwargs):
+        return _wrapped_call(self.obj, self.name, self.f, args, kwargs)
+
+def _wrapped_callable(obj, name, f):
+    if isinstance(f, _CallableWrapper):
+        return f
+    else:
+        return _CallableWrapper(obj, name, f)
+
 def _wrapped_call(obj, name, f, args, kwargs):
     '''
     Used for handling call to returned callables of get
