@@ -29,6 +29,5 @@ __docformat__ = 'reStructuredText'
 
 # place these in our namespace, naughty naughty
 from .delegationaspect import DelegationAspect
-from .profile import Profile
-from .decorators import profile_carrier, in_profile
+from .decorators import mapped_class, mapped
 
