@@ -18,8 +18,6 @@
 
 __docformat__ = 'reStructuredText'
 
-# TODO: document on the wiki, also document DiscreteRectangle
-
 # Note: None of these support mangling. It can't know about the class it
 # resides in, so it can't mangle for them, and it can't use the descriptor's
 # obj param as derived classes mangle differently than their base. So mangling
@@ -27,6 +25,7 @@ __docformat__ = 'reStructuredText'
 
 from .attributedescriptor import AttributeDescriptor
 from .dereferenceddescriptor import DereferencedDescriptor
+from .dereferencedbounddescriptor import DereferencedBoundDescriptor
 from .bounddescriptor import BoundDescriptor
 from .restricteddescriptor import RestrictedDescriptor
 
