@@ -18,31 +18,20 @@
 
 __docformat__ = 'reStructuredText'
 
-class AttributeDescriptor(object):
+def AttributeDescriptor(attr_name):
 
     '''
-    A wrapper that makes an attribute look like a descriptor.
+    Construct a wrapper that makes an attribute look like a descriptor.
 
     The descriptor supports all access (get, set, del).
+
+    :param attr_name: Name of the attribute to get
+    :type attr_name: string
     '''
 
-    def __init__(self, attr_name):
-        '''
-        Construct an AttributeDescriptor.
-
-        :param attr_name: Name of the attribute to get, cannot contain any
-        dots. No mangling is done.
-        :type attr_name: string
-        '''
-        self.__attr_name = attr_name
-
-    def __get__(self, obj, objtype = None):
-        return getattr(obj, self.__attr_name)
-
-    def __set__(self, obj, value):
-        setattr(obj, self.__attr_name, value)
-
-    def __delete__(self, obj):
-        delattr(obj, self.__attr_name)
-
+    return property(
+        lambda self: getattr(self, attr_name),
+        lambda self, value: setattr(self, attr_name, value),
+        lambda self: delattr(self, attr_name)
+    )
 
