@@ -16,14 +16,13 @@
 # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-# Note: this file name isn't standard as epydoc and our testing couldn't
-# understand it if we named it dispatcher.py; it would clash in __init__.py
+# Note: named this module with _ suffix so that it doesn't clash in __init__.py
 # with the dispatcher decorator
 
 __docformat__ = 'reStructuredText'
 
 from pytilities.delegation import (
-    profile_carrier, in_profile)
+    mapped_class, mapped)
 
 class UnsupportedEventError(Exception):
     """Tried to access an unregistered event"""
@@ -31,7 +30,7 @@ class UnsupportedEventError(Exception):
     def __init__(self, event_name):
         Exception.__init__(self, "Unsupported event: %s" % event_name)
 
-@profile_carrier
+@mapped_class
 class Dispatcher(object):
 
     """
@@ -49,12 +48,15 @@ class Dispatcher(object):
 
     # inspired by pyglet.event.EventDispatcher, yay pyglet
 
+    public_mapping = {}
+    default_mapping = {}
+
     def __init__(self):
         # dict of handlers: event_name -> set((handler, owner))
         self.__handlers = {}
         self.__registered_events = set()
 
-    @in_profile("public")
+    @mapped(public_mapping)
     def add_handler(self, event_name, handler, owner = None):
         """
         Add handler for an event, optionally with an owner.
@@ -84,7 +86,7 @@ class Dispatcher(object):
         self.__handlers.setdefault(event_name, set())
         self.__handlers[event_name].add((handler, owner))
 
-    @in_profile("public")
+    @mapped(public_mapping)
     def remove_handlers(self, event_name=None, owner=None):
         """
         Remove all or some handlers of the dispatcher.
@@ -113,7 +115,7 @@ class Dispatcher(object):
         handlers -= set((handler, o) for (handler, o) in handlers 
                         if o is owner)
 
-    @in_profile("public")
+    @mapped(public_mapping)
     def remove_handler(self, event_name, handler, owner = None):
         """
         Remove a handler from an event. It is an error to try to remove a
@@ -139,7 +141,7 @@ class Dispatcher(object):
 
         self.__handlers[event_name].remove((handler, owner))
 
-    @in_profile()
+    @mapped(default_mapping)
     def dispatch(self, event_name, *args, **keyword_args):
         """
         Dispatch an event to its handlers. 
@@ -162,7 +164,7 @@ class Dispatcher(object):
         for handler in self.__handlers.get(event_name, ()):
             handler[0](*args, **keyword_args)
 
-    @in_profile("public")
+    @mapped(public_mapping)
     def event(self, event_name, owner = None):
         """
         Register the decorated as a handler of `event_name`
@@ -182,7 +184,7 @@ class Dispatcher(object):
 
         return decorator
 
-    @in_profile()
+    @mapped(default_mapping)
     def register_events(self, *event_names):
         """
         Register events.
@@ -195,7 +197,7 @@ class Dispatcher(object):
         # call that a duck)
         self.__registered_events.update(event_names)
 
-    @in_profile("public")
+    @mapped(public_mapping)
     def has_event(self, event_name):
         """
         Checks if `event_name` is supported
@@ -207,7 +209,7 @@ class Dispatcher(object):
         """
         return event_name in self.__registered_events
 
-    @in_profile("public")
+    @mapped(public_mapping)
     @property
     def events(self):
         """
@@ -217,5 +219,4 @@ class Dispatcher(object):
         """
         return frozenset(self.__registered_events)
 
-profiles = Dispatcher.attribute_profiles
-profiles['default'] |= profiles['public']
+Dispatcher.default_mapping.update(Dispatcher.public_mapping)
