@@ -18,11 +18,11 @@
 
 __docformat__ = 'reStructuredText'
 
-from pytilities.delegation import in_profile, profile_carrier
+from pytilities.delegation import mapped, mapped_class
 from . import UnsupportedEventError
 
-@profile_carrier()
-class DispatcherSwitch(object):
+@mapped_class()
+class DispatcherSwitch(object): # DispatcherChain may have been a better name
 
     """
     Provides a single interface to multiple event dispatchers.
@@ -44,6 +44,8 @@ class DispatcherSwitch(object):
         - ...
     """
 
+    public_mapping = {}
+
     def __init__(self):
         self.__dispatchers = []
 
@@ -69,12 +71,12 @@ class DispatcherSwitch(object):
         else:
             raise UnsupportedEventError(event_name)
 
-    @in_profile('public')
+    @mapped(public_mapping)
     def add_handler(self, event_name, handler, owner = None):
         dispatcher = self.__get_dispatcher_for_event(event_name)
         dispatcher.add_handler(event_name, handler, owner)
 
-    @in_profile('public')
+    @mapped(public_mapping)
     def remove_handlers(self, event_name=None, owner=None):
         # Run through our supported events, remove all handlers for each
         # supported event on the first dispatcher that supports it
@@ -86,12 +88,12 @@ class DispatcherSwitch(object):
                 dispatcher = self.__get_dispatcher_for_event(event)
                 dispatcher.remove_handlers(event, owner)
 
-    @in_profile('public')
+    @mapped(public_mapping)
     def remove_handler(self, event_name, handler, owner = None):
         dispatcher = self.__get_dispatcher_for_event(event_name)
         dispatcher.remove_handler(event_name, handler, owner)
 
-    @in_profile('public')
+    @mapped(public_mapping)
     def event(self, event_name, owner=None):
         def decorator(handler):
             self.add_handler(event_name, handler, owner)
@@ -99,7 +101,7 @@ class DispatcherSwitch(object):
 
         return decorator
 
-    @in_profile('public')
+    @mapped(public_mapping)
     def has_event(self, event_name):
         for dispatcher in self.__dispatchers:
             if dispatcher.has_event(event_name):
@@ -107,7 +109,7 @@ class DispatcherSwitch(object):
         else:
             return False
 
-    @in_profile('public')
+    @mapped(public_mapping)
     @property
     def events(self):
         events = set()
@@ -119,5 +121,3 @@ class DispatcherSwitch(object):
         dispatcher.dispatch(event_name, *args, **keyword_args)
 
 
-#profiles = DispatcherSwitch._profiles
-#profiles['default'] |= profiles['public']
