@@ -22,6 +22,7 @@ from pytilities import aop, get_annotations
 from pytilities.event import Dispatcher
 from pytilities.aop import Aspect
 from pytilities.delegation import DelegationAspect
+from pytilities.dictionary import FunctionMap
 
 class VerboseRectangleAspect(Aspect):
     
@@ -33,7 +34,15 @@ class VerboseRectangleAspect(Aspect):
         Aspect.__init__(self)
 
         # advice to dispatch when needed
-        self._advise('*', call=self.watch_size, set_=self.watch_size)
+        self._advice_mappings = FunctionMap(self._mapper)
+        self._undefined_keys = True
+
+    def _mapper(self, key):
+        access, attribute_name = key
+        if access in ('call', 'set'):
+            return self.watch_size
+        else:
+            return None
 
     def apply(self, obj):
         if not self.is_applied(obj):
@@ -58,7 +67,7 @@ class VerboseRectangleAspect(Aspect):
 
 delegation_aspect = DelegationAspect(
     property(lambda s: get_annotations(s)['dispatcher']),
-    Dispatcher.attribute_profiles['public'])
+    Dispatcher.public_mapping)
 
 verbose_rectangle_aspect = VerboseRectangleAspect()
 del VerboseRectangleAspect
