@@ -22,6 +22,7 @@ from pytilities import aop, get_annotations
 from pytilities.event import Dispatcher
 from pytilities.aop import Aspect
 from pytilities.delegation import DelegationAspect
+from pytilities.dictionary import FunctionMap
 
 class VerboseVectorAspect(Aspect):
     
@@ -33,7 +34,15 @@ class VerboseVectorAspect(Aspect):
         Aspect.__init__(self)
 
         # advice to dispatch when needed
-        self._advise('*', call=self.watch_xy, set_=self.watch_xy)
+        self._advice_mappings = FunctionMap(self._mapper)
+        self._undefined_keys = True
+
+    def _mapper(self, key):
+        access, attribute_name = key
+        if access in ('call', 'set'):
+            return self.watch_xy
+        else:
+            return None
 
     def apply(self, obj):
         if not self.is_applied(obj):
@@ -59,7 +68,7 @@ class VerboseVectorAspect(Aspect):
 
 delegation_aspect = DelegationAspect(
     property(lambda s: get_annotations(s)['dispatcher']),
-    Dispatcher.attribute_profiles['public'])
+    Dispatcher.public_mapping)
 
 verbose_vector_aspect = VerboseVectorAspect()
 del VerboseVectorAspect
