@@ -27,6 +27,9 @@ def overloaded(overloads, is_method = True):
     The decorated operation is replaced entirely, its docstring is copied to
     the replacement operation.
 
+    The returned operation has a process_args function, see
+    `Overloader.process_args` for documentation.
+
     Parameters:
 
         `overloads` :: (Overload...)
@@ -61,10 +64,11 @@ def overloaded(overloads, is_method = True):
 
     # replacement for the decorated
     def __overloaded(*args, **kwargs):
-        return overloader.process_call(args, kwargs)
+        return overloader.process_call(*args, kwargs=kwargs)
 
     def _overloaded(f):
         __overloaded.__doc__ = f.__doc__
+        __overloaded.process_args = overloader.process_args
         return __overloaded
 
     return _overloaded
