@@ -20,10 +20,10 @@ __docformat__ = 'reStructuredText'
 
 from . import _NumberTypeMeta
 
-class NumberType(object):
+class NumberType(object, metaclass=_NumberTypeMeta):
     """
     Represents any number type.
     
-    Ints (, longs) and floats are subclasses of this class.
+    Ints, floats and infinity are subclasses of this class.
     """
-    __metaclass__ = _NumberTypeMeta
+
